@@ -2,7 +2,7 @@
 ASGI App using dataclasses module for request/response objects
 """
 
-__version__ = '0.18.0'
+__version__ = '0.23.0'
 
 from apidaora.app import appdaora
 from apidaora.bodies import GZipFactory
@@ -12,10 +12,12 @@ from apidaora.exceptions import BadRequestError
 from apidaora.header import Header
 from apidaora.method import MethodType
 from apidaora.middlewares import (
+    AsyncBackgroundTaskMiddleware,
+    BackgroundTaskMiddleware,
     CorsMiddleware,
+    LockRequestMiddleware,
     MiddlewareRequest,
     Middlewares,
-    PreventRequestMiddleware,
 )
 from apidaora.responses import (
     Response,
@@ -46,5 +48,7 @@ __all__ = [
     'CorsMiddleware',
     'MiddlewareRequest',
     'ClassController',
-    'PreventRequestMiddleware',
+    'LockRequestMiddleware',
+    'BackgroundTaskMiddleware',
+    'AsyncBackgroundTaskMiddleware',
 ]
